@@ -1812,7 +1812,7 @@ static gchar *report_create_jobname(GncPluginPageReportPrivate *priv)
         char *format_code = gnc_prefs_get_string (GNC_PREFS_GROUP_REPORT_PDFEXPORT,
                                                   GNC_PREF_FILENAME_DATE_FMT);
         const gchar *date_format_string;
-        if (*format_code == '\0')
+        if (!(format_code && *format_code))
         {
             g_free(format_code);
             format_code = g_strdup("locale");
@@ -1872,8 +1872,17 @@ static gchar *report_create_jobname(GncPluginPageReportPrivate *priv)
         // Look up the sprintf format of the output name from the preferences database
         char* format = gnc_prefs_get_string(GNC_PREFS_GROUP_REPORT_PDFEXPORT, GNC_PREF_FILENAME_FMT);
 
-        job_name = g_strdup_printf(format, report_name, report_number, job_date);
-
+        if (format && *format)
+        {
+            job_name = g_strdup_printf(format, report_name,
+                                       report_number, job_date);
+        }
+        else
+        {
+            PWARN("No GNC_PREF_FILENAME_FMT!");
+            job_name = g_strdup_printf ("%s %s %s", report_name,
+                                         report_number, job_date);
+        }
         g_free(format);
     }
     g_free (report_name);
@@ -1965,13 +1974,16 @@ gnc_plugin_page_report_exportpdf_cb( GtkAction *action, GncPluginPageReport *rep
             // Yes. In the kvp, look up the key for the Export-PDF output
             // directory. If it exists, prepend this to the job name so that
             // we can export to PDF.
-	    if (dirname && g_file_test(dirname,
-				       G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR))
-	    {
-		gchar *tmp = g_build_filename(dirname, job_name, NULL);
-		g_free(job_name);
-		job_name = tmp;
-	    }
+            if (dirname)
+            {
+                if (g_file_test (dirname, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR))
+                {
+                    gchar *tmp = g_build_filename (dirname, job_name, NULL);
+                    g_free (job_name);
+                    job_name = tmp;
+                }
+                g_free (dirname);
+            }
         }
     }
 
