@@ -614,11 +614,21 @@ int ofx_proc_transaction_cb(struct OfxTransactionData data, void *user_data)
             /* set tran-num and/or split-action per book option */
             if (data.check_number_valid)
             {
-                gnc_set_num_action(transaction, split, data.check_number, NULL);
+                /* SQL will correctly interpret the string "null", but
+                 * the transaction num field is declared to be
+                 * non-null so substitute the empty string.
+                 */
+                const char *num_value =
+                    strcasecmp (data.check_number, "null") == 0 ? "" :
+                    data.check_number;
+                gnc_set_num_action(transaction, split, num_value, NULL);
             }
             else if (data.reference_number_valid)
             {
-                gnc_set_num_action(transaction, split, data.reference_number, NULL);
+                const char *num_value =
+                    strcasecmp (data.reference_number, "null") == 0 ? "" :
+                    data.check_number;
+                gnc_set_num_action(transaction, split, num_value, NULL);
             }
             /* Also put the ofx transaction's memo in the
              * split's memo field */
@@ -873,6 +883,8 @@ int ofx_proc_transaction_cb(struct OfxTransactionData data, void *user_data)
 
                     // Set split memo from ofx transaction name or memo
                     gnc_ofx_set_split_memo(&data, split);
+                    if (data.fi_id_valid)
+                        gnc_import_set_split_online_id (split, sanitize_string (data.fi_id));
                 }
                 if (income_account != NULL &&
                         data.invtransactiontype == OFX_INCOME)
@@ -889,6 +901,8 @@ int ofx_proc_transaction_cb(struct OfxTransactionData data, void *user_data)
 
                     // Set split memo from ofx transaction name or memo
                     gnc_ofx_set_split_memo(&data, split);
+                    if (data.fi_id_valid)
+                        gnc_import_set_split_online_id (split, sanitize_string (data.fi_id));
                 }
             }
 
@@ -907,6 +921,8 @@ int ofx_proc_transaction_cb(struct OfxTransactionData data, void *user_data)
 
                 // Set split memo from ofx transaction name or memo
                 gnc_ofx_set_split_memo(&data, split);
+                if (data.fi_id_valid)
+                    gnc_import_set_split_online_id (split, sanitize_string (data.fi_id));
             }
         }
 
