@@ -1389,12 +1389,11 @@ gnc_split_register_get_price_entry (VirtualLocation virt_loc,
 
     split = gnc_split_register_get_split (reg, virt_loc.vcell_loc);
 
-    if (gnc_numeric_zero_p (xaccSplitGetAmount(split)) ||
-        gnc_numeric_zero_p (xaccSplitGetValue(split)))
-        return NULL;
-
     price = xaccSplitGetSharePrice (split);
     curr = xaccTransGetCurrency (xaccSplitGetParent (split));
+    if (gnc_numeric_zero_p (price))
+        return NULL;
+
     return xaccPrintAmount (price, gnc_default_price_print_info (curr));
 }
 
