@@ -1362,12 +1362,22 @@ gnucash_sheet_button_release_event (GtkWidget *widget, GdkEventButton *event)
     return TRUE;
 }
 
+static float
+clamp_scrollable_value (float value, GtkAdjustment* adj)
+{
+    float lower = gtk_adjustment_get_lower (adj);
+    float upper = gtk_adjustment_get_upper (adj);
+    float size = gtk_adjustment_get_page_size (adj);
+    return CLAMP(value, lower, upper - size);
+
+}
 static gboolean
 gnucash_scroll_event (GtkWidget *widget, GdkEventScroll *event)
 {
     GnucashSheet *sheet;
     GtkAdjustment *vadj;
-    gfloat v_value;
+    gfloat h_value, v_value;
+    int direction;
 
     g_return_val_if_fail (widget != NULL, TRUE);
     g_return_val_if_fail (GNUCASH_IS_SHEET(widget), TRUE);
@@ -1385,18 +1395,27 @@ gnucash_scroll_event (GtkWidget *widget, GdkEventScroll *event)
     case GDK_SCROLL_DOWN:
         v_value += gtk_adjustment_get_step_increment (vadj);
         break;
+/* GdkQuartz reserves GDK_SCROLL_SMOOTH for high-resolution touchpad
+ * scrolling events, and in that case scrolling by line is much too
+ * fast. Gdk/Wayland and Gdk/Win32 pass GDK_SCROLL_SMOOTH for all
+ * scroll-wheel events and expect coarse resolution.
+ */
     case GDK_SCROLL_SMOOTH:
-        if (event->delta_y < 0)
-            v_value -= gtk_adjustment_get_step_increment (vadj);
-        if (event->delta_y > 0)
-            v_value += gtk_adjustment_get_step_increment (vadj);
+        h_value = gtk_adjustment_get_value (sheet->hadj);
+        h_value += event->delta_x;
+        h_value = clamp_scrollable_value (h_value, sheet->hadj);
+        gtk_adjustment_set_value (sheet->hadj, h_value);
+#if defined MAC_INTEGRATION
+        v_value += event->delta_y;
+#else
+        direction = event->delta_y > 0 ? 1 : event->delta_y < 0 ? -1 : 0;
+        v_value += gtk_adjustment_get_step_increment (vadj) * direction;
+#endif
         break;
     default:
         return FALSE;
     }
-    v_value = CLAMP(v_value, gtk_adjustment_get_lower (vadj),
-              gtk_adjustment_get_upper (vadj) - gtk_adjustment_get_page_size (vadj));
-
+    v_value = clamp_scrollable_value (v_value, vadj);
     gtk_adjustment_set_value (vadj, v_value);
 
     if (event->delta_y == 0)
